# bowtie2

**DOI:** [10.5281/zenodo.5765688](https://doi.org/10.5281/zenodo.5765688)

## Available Versions
- **Version 2.3.4**
  - [Download](https://zenodo.org/record/5765689/files/bowtie2_2.3.4.img)
  - **MD5:** `130055d18ea89b2c5ff966a0ead6f02a`
  - **DOI:** [10.5281/zenodo.5765689](https://doi.org/10.5281/zenodo.5765689)
  - **Size:** 67.91 MB
  - **Binaries:** 0 available

- **Version 2.4.2**
  - [Download](https://zenodo.org/record/5765690/files/bowtie2_2.4.2.img)
  - **MD5:** `9db75746d96f3b67e599168c9f48fc8b`
  - **DOI:** [10.5281/zenodo.5765690](https://doi.org/10.5281/zenodo.5765690)
  - **Size:** 68.68 MB
  - **Binaries:** 0 available

- **Version 2.5.1**
  - [Download](https://zenodo.org/record/8092297/files/bowtie2_2.5.1.img)
  - **MD5:** `35eb769d82ff9f64a83aa69fc1b0f55b`
  - **DOI:** [10.5281/zenodo.8092297](https://doi.org/10.5281/zenodo.8092297)
  - **Size:** 67.91 MB
  - **Binaries:** 0 available

## Binaries (9 total)

```bowtie2 bowtie2-build bowtie2-inspect bowtie2-align-l bowtie2-build-l bowtie2-inspect-l bowtie2-align-s bowtie2-build-s bowtie2-inspect-s```
